@@ -1,2 +1,2 @@
 from ..channels import *
-from ..pb2 import *
+from .msg_utils import *
