@@ -31,10 +31,7 @@ class AbstractMsgHandler(abc.ABC):
 
     @abc.abstractmethod
     def handle_msg(self, message: _message.Message):
-        """
-        :param message: Message
-        :return:
-        """
+        pass
 
     def parse_msg(self, body_data):
         if self.msg_clazz == Message:
