@@ -1,7 +1,7 @@
 import asyncio
 import logging
 from asyncio.futures import Future
-from typing import Any, Union, Set, Optional
+from typing import Any, Set, Optional
 
 from google.protobuf import message as _message
 
@@ -18,12 +18,15 @@ if log.level == logging.NOTSET:
 browser = _browser()
 websocket = _websocket()
 
-"""
-批量获取机器人设备监听类
-"""
-
 
 def set_log_level(level: int, save_file: str = None):
+    """设置sdk日志级别
+
+    Args:
+        level: logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR
+        save_file: 需要保存到文件的, 填写日志文件路径
+
+    """
     log.setLevel(level)
 
     from .dns.dns_browser import log as log1
@@ -40,27 +43,50 @@ def set_log_level(level: int, save_file: str = None):
 
 
 class GetWiFiDeviceListListener(WiFiDeviceListener):
-    devices: Union[Set[Any], Any]
+    """批量获取机器人设备监听类
+
+    Args:
+        devices: Set[WiFiDevice] or None
+    """
+    devices: Set[WiFiDevice]
 
     def __init__(self, devices):
-        self.devices = devices or set()
+        self.devices: Set[WiFiDevice] = devices or set()
 
     def on_device_updated(self, device: WiFiDevice) -> None:
-        pass
+        """
+        机器人设备更新了
+        Args:
+            device: WiFiDevice
+        """
+        self.devices.update(device)
 
     def on_device_removed(self, device: WiFiDevice) -> None:
+        """
+        机器人设备从局域网中移除了
+        Args:
+            device: WFiDevice
+        """
         self.devices.remove(device)
 
     def on_device_found(self, device: WiFiDevice) -> None:
+        """
+        扫描到一个机器人设备
+        Args:
+            device: WFiDevice
+        """
         self.devices.add(device)
 
 
-"""
-获取用户选择的机器人序号
-"""
-
-
 async def get_user_input(devices: tuple) -> int:
+    """
+    获取用户输入
+    Args:
+        devices: 扫描到的机器人设备
+
+    Returns:
+        int : 用户输入值
+    """
     try:
         i: int = 0
         for device in devices:
@@ -73,12 +99,16 @@ async def get_user_input(devices: tuple) -> int:
         return int(num_text)
 
 
-"""
-开启一个扫描机器人设备的任务
-"""
-
-
 def start_scan(loop: asyncio.AbstractEventLoop, name: str) -> Future:
+    """
+    开启一个扫描机器人设备的Future
+    Args:
+        loop: 当前事件loop
+        name: 指定设备名称
+
+    Returns:
+        asyncio.Future
+    """
     fut = loop.create_future()
 
     class _InnerLister(WiFiDeviceListener):
@@ -117,12 +147,17 @@ def start_scan(loop: asyncio.AbstractEventLoop, name: str) -> Future:
     return fut
 
 
-"""
-获取当前局域网内，指定名字的机器人设备信息
-"""
-
-
 async def get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
+    """
+    获取当前局域网内，指定名字的机器人设备信息
+    Args:
+        name: 设备序列号
+        timeout: 扫描超时时间
+
+    Returns:
+        Optional[WiFiDevice]
+    """
+
     async def start_scan_async():
         return await start_scan(asyncio.get_running_loop(), name)
 
@@ -137,12 +172,15 @@ async def get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
         log.info("stop scan finished.")
 
 
-"""
-获取当前局域网内所有机器人设备信息
-"""
+async def get_device_list(timeout: int) -> tuple:
+    """
+    获取当前局域网内所有机器人设备信息
+    Args:
+        timeout: 超时时间
 
-
-async def get_device_list(timeout: int):
+    Returns:
+        Optional[WiFiDevice]
+    """
     devices: Set[WiFiDevice] = set()
     browser.add_listener(GetWiFiDeviceListListener(devices))
     browser.start_scan(0)
@@ -152,46 +190,54 @@ async def get_device_list(timeout: int):
     return tuple(devices)
 
 
-"""
-链接机器人设备
-"""
-
-
 async def connect(device: WiFiDevice) -> bool:
+    """
+    连接机器人设备
+
+    Args:
+        device (WiFiDevice): 指定机器人设备对象
+
+    Returns:
+        bool: 是否连接设备成功
+
+    """
     return await websocket.connect(device.address)
 
 
-"""
-注册命令监听器
-"""
-
-
 def register_msg_handler(cmd: int, handler: AbstractMsgHandler):
+    """
+    注册命令监听器
+    Args:
+        cmd: 支持的命令请查看: mini.blockapi.cmdid
+        handler: 命令处理器
+
+    """
     websocket.register_msg_handler(cmd, handler)
 
 
-"""
-反注册命令监听器
-"""
-
-
 def unregister_msg_handler(cmd: int, handler: AbstractMsgHandler):
+    """
+    反注册命令监听器
+    Args:
+        cmd: 支持的命令请查看: mini.blockapi.cmdid
+        handler: 命令处理器
+    """
     websocket.unregister_msg_handler(cmd, handler)
 
 
-"""
-发送一个消息给机器人
-"""
-
-
 async def send_msg(cmd: int, message: _message.Message, timeout: int) -> Any:
+    """
+    发送一个消息给机器人
+    Args:
+        cmd:支持的命令请查看: mini.blockapi.cmdid
+        message:  消息类在: mini.pb2 包内
+        timeout: 超时时间
+    """
     return await websocket.send_msg(cmd, message, timeout)
 
 
-"""
-断开链接，释放资源
-"""
-
-
 async def release():
+    """
+    断开链接，释放资源
+    """
     await websocket.shutdown()
